Added README and simpleeventcatcher, which i forgot to add to last commit
diff --git a/filesystemwatcher/filesystemwatcher.cpp b/filesystemwatcher/filesystemwatcher.cpp
index 79363e8..b887292 100644
--- a/filesystemwatcher/filesystemwatcher.cpp
+++ b/filesystemwatcher/filesystemwatcher.cpp
@@ -50,7 +50,13 @@
 void FileSystemWatcher::bootstrap()
 {
     // bootstrap specific steps
+#if DEBUG
+    qDebug() << endl << "[BOOTSTRAP]";
+#endif
     timerCallbackSlot();
+#if DEBUG
+    qDebug() << endl << "[\\BOOTSTRAP]";
+#endif
 }
 
 void FileSystemWatcher::watcherCallbackSlot(QString dirPath)
@@ -82,8 +88,9 @@
     // DEBUG: Print Changes
     printChanges(dirChanges);
 #endif
-    // emit the signal
-    emit dirEventSignal(dirChanges);
+    // emit the signal if not empty
+    if(!dirChanges.empty())
+        emit dirEventSignal(dirChanges);
 }
 
 QHash<QString, qint64> FileSystemWatcher::scanDirectory(QString dirPath)